package com.build.domain.product.composite;

import java.io.Serializable;
import java.util.List;

import com.build.domain.category.BreadcrumbTrailItem;
import com.build.domain.product.ProductImageGallery;
import com.build.domain.product.ProductQuestion;
import com.build.domain.product.specs.ProductSpec;

public class ProductComposite implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	private Integer productCompositeId;
	private String manufacturer;
	private String productId;

	private String title;
	private String series;
	private String seriesDescription;
	private Boolean shipsForeign;
	private String finishAlias;
	private String application;
	private String handleType;
	private String type;
	private Boolean freight;
	private Double freightCost;
	private Boolean freeShipping;

	private List<ProductImageGallery> imageGallery;

	private ReviewRating reviewRating;

	private Boolean availableByLocation;
	private Boolean squareFootageBased;
	private Boolean hasServices;
	private Boolean hasReplacementParts;

	private List<ProductVideo> productVideos;

	private String description;

	private List<ProductAttachment> attachments;

	private List<AlternateSku> alternateSkus;

	private ManufacturerInfo manufacturerInfo;

	// internal info
	private List<ProductVendorInfo> productVendorInfo; // internal
	private BrandManagerInfo brandManagerInfo; // internal
	private List<ProductInternalNote> internalNotes; // internal

	private List<RelatedProductView> replacementProductViews; // site-specific
	private List<RelatedProductView> accessories; // site-specific
	private List<RelatedProductView> relatedProducts; // site-specific
	private List<RecommendedOption> recommendedOptions; // site-specific

	private List<ProductSpec> productSpecs;

	private List<ProductFinishView> finishes;

	private List<PricedOptionGroup> pricedOptionGroups;

	private List<Rebate> manufacturerRebates;

	private List<ProductQuestion> productQuestions;

	private boolean discontinued;
	private List<BreadcrumbTrailItem> breadcrumbTrail;
	private String manufacturerImage;
	private boolean preOrder;
	private boolean freeInstallation;
	private String containerType;

	// onSite flags
	private Boolean onKitchenDirect;
	private Boolean onFaucetDirect;
	private Boolean onToolsDirect;
	private Boolean onMoreHome;
	private Boolean onLightingDirect;
	private Boolean onITankless;
	private Boolean onStockBlowout;
	private Boolean onVentingDirect;
	private Boolean onPullsDirect;
	private Boolean onFaucetDirectCoUk;
	private Boolean onHandlesets;
	private Boolean onLightingCentral;
	private Boolean onDrillSpot;
	private Boolean onFixturesDirect;
	private Boolean onImprovementDirectReMerch;
	private Boolean onDoorsDirect;
	private Boolean onVentingPipe;
	private Boolean onFergusonCounters;
	private Boolean onShopStockBuilding;
	private Boolean onBathFans;
	private Boolean onRangeHoodsDirect;
	private Boolean onShowerSystemsDirect;
	private Boolean onJustChandeliers;
	private Boolean onB2bChannel;
	private Boolean onKnobsets;
	private Boolean onImprovementDirect;
	private Boolean onPlumbingDirect;
	private Boolean onBuild;
	private Boolean onFaucet;
	private Boolean onLightingShowplace;
	private Boolean onFloorMall;

	public Integer getProductCompositeId() {
		return productCompositeId;
	}

	public void setProductCompositeId(Integer productCompositeId) {
		this.productCompositeId = productCompositeId;
	}

	public String getManufacturer() {
		return manufacturer;
	}

	public void setManufacturer(String manufacturer) {
		this.manufacturer = manufacturer;
	}

	public String getProductId() {
		return productId;
	}

	public void setProductId(String productId) {
		this.productId = productId;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getSeries() {
		return series;
	}

	public void setSeries(String series) {
		this.series = series;
	}

	public String getSeriesDescription() {
		return seriesDescription;
	}

	public void setSeriesDescription(String seriesDescription) {
		this.seriesDescription = seriesDescription;
	}

	public List<ProductImageGallery> getImageGallery() {
		return imageGallery;
	}

	public void setImageGallery(List<ProductImageGallery> imageGallery) {
		this.imageGallery = imageGallery;
	}

	public List<RelatedProductView> getReplacementProductViews() {
		return replacementProductViews;
	}

	public void setReplacementProductViews(
			List<RelatedProductView> replacementProductViews) {
		this.replacementProductViews = replacementProductViews;
	}

	public Boolean getShipsForeign() {
		return shipsForeign;
	}

	public void setShipsForeign(Boolean shipsForeign) {
		this.shipsForeign = shipsForeign;
	}

	public ReviewRating getReviewRating() {
		return reviewRating;
	}

	public void setReviewRating(ReviewRating reviewRating) {
		this.reviewRating = reviewRating;
	}

	public String getFinishAlias() {
		return finishAlias;
	}

	public void setFinishAlias(String finishAlias) {
		this.finishAlias = finishAlias;
	}

	public String getApplication() {
		return application;
	}

	public void setApplication(String application) {
		this.application = application;
	}

	public String getHandleType() {
		return handleType;
	}

	public void setHandleType(String handleType) {
		this.handleType = handleType;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public Boolean getFreight() {
		return freight;
	}

	public void setFreight(Boolean freight) {
		this.freight = freight;
	}

	public Double getFreightCost() {
		return freightCost;
	}

	public void setFreightCost(Double freightCost) {
		this.freightCost = freightCost;
	}

	public Boolean getFreeShipping() {
		return freeShipping;
	}

	public void setFreeShipping(Boolean freeShipping) {
		this.freeShipping = freeShipping;
	}

	public Boolean getAvailableByLocation() {
		return availableByLocation;
	}

	public void setAvailableByLocation(Boolean availableByLocation) {
		this.availableByLocation = availableByLocation;
	}

	public Boolean getSquareFootageBased() {
		return squareFootageBased;
	}

	public void setSquareFootageBased(Boolean squareFootageBased) {
		this.squareFootageBased = squareFootageBased;
	}

	public Boolean getHasServices() {
		return hasServices;
	}

	public void setHasServices(Boolean hasServices) {
		this.hasServices = hasServices;
	}

	public Boolean getHasReplacementParts() {
		return hasReplacementParts;
	}

	public void setHasReplacementParts(Boolean hasReplacementParts) {
		this.hasReplacementParts = hasReplacementParts;
	}

	public List<ProductVideo> getProductVideos() {
		return productVideos;
	}

	public void setProductVideos(List<ProductVideo> productVideos) {
		this.productVideos = productVideos;
	}

	public List<RecommendedOption> getRecommendedOptions() {
		return recommendedOptions;
	}

	public void setRecommendedOptions(List<RecommendedOption> recommendedOptions) {
		this.recommendedOptions = recommendedOptions;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public List<ProductAttachment> getAttachments() {
		return attachments;
	}

	public void setAttachments(List<ProductAttachment> attachments) {
		this.attachments = attachments;
	}

	public List<AlternateSku> getAlternateSkus() {
		return alternateSkus;
	}

	public void setAlternateSkus(List<AlternateSku> alternateSkus) {
		this.alternateSkus = alternateSkus;
	}

	public ManufacturerInfo getManufacturerInfo() {
		return manufacturerInfo;
	}

	public void setManufacturerInfo(ManufacturerInfo manufacturerInfo) {
		this.manufacturerInfo = manufacturerInfo;
	}

	public List<ProductVendorInfo> getProductVendorInfo() {
		return productVendorInfo;
	}

	public void setProductVendorInfo(List<ProductVendorInfo> productVendorInfo) {
		this.productVendorInfo = productVendorInfo;
	}

	public BrandManagerInfo getBrandManagerInfo() {
		return brandManagerInfo;
	}

	public void setBrandManagerInfo(BrandManagerInfo brandManagerInfo) {
		this.brandManagerInfo = brandManagerInfo;
	}

	public List<ProductInternalNote> getInternalNotes() {
		return internalNotes;
	}

	public void setInternalNotes(List<ProductInternalNote> internalNotes) {
		this.internalNotes = internalNotes;
	}

	public List<RelatedProductView> getAccessories() {
		return accessories;
	}

	public void setAccessories(List<RelatedProductView> accessories) {
		this.accessories = accessories;
	}

	public List<RelatedProductView> getRelatedProducts() {
		return relatedProducts;
	}

	public void setRelatedProducts(List<RelatedProductView> relatedProducts) {
		this.relatedProducts = relatedProducts;
	}

	public List<ProductSpec> getProductSpecs() {
		return productSpecs;
	}

	public void setProductSpecs(List<ProductSpec> productSpecs) {
		this.productSpecs = productSpecs;
	}

	public List<ProductFinishView> getFinishes() {
		return finishes;
	}

	public void setFinishes(List<ProductFinishView> finishes) {
		this.finishes = finishes;
	}

	public List<PricedOptionGroup> getPricedOptionGroups() {
		return pricedOptionGroups;
	}

	public void setPricedOptionGroups(List<PricedOptionGroup> pricedOptionGroups) {
		this.pricedOptionGroups = pricedOptionGroups;
	}

	public List<Rebate> getManufacturerRebates() {
		return manufacturerRebates;
	}

	public void setManufacturerRebates(List<Rebate> manufacturerRebates) {
		this.manufacturerRebates = manufacturerRebates;
	}

	public boolean isDiscontinued() {
		return discontinued;
	}

	public void setDiscontinued(boolean discontinued) {
		this.discontinued = discontinued;
	}

	public List<BreadcrumbTrailItem> getBreadcrumbTrail() {
		return breadcrumbTrail;
	}

	public void setBreadcrumbTrail(List<BreadcrumbTrailItem> breadcrumbTrail) {
		this.breadcrumbTrail = breadcrumbTrail;
	}

	public String getManufacturerImage() {
		return manufacturerImage;
	}

	public void setManufacturerImage(String manufacturerImage) {
		this.manufacturerImage = manufacturerImage;
	}

	public boolean isPreOrder() {
		return preOrder;
	}

	public void setPreOrder(boolean preOrder) {
		this.preOrder = preOrder;
	}

	public boolean isFreeInstallation() {
		return freeInstallation;
	}

	public void setFreeInstallation(boolean freeInstallation) {
		this.freeInstallation = freeInstallation;
	}

	public String getContainerType() {
		return containerType;
	}

	public void setContainerType(String containerType) {
		this.containerType = containerType;
	}

	public Boolean getOnKitchenDirect() {
		return onKitchenDirect;
	}

	public void setOnKitchenDirect(Boolean onKitchenDirect) {
		this.onKitchenDirect = onKitchenDirect;
	}

	public Boolean getOnFaucetDirect() {
		return onFaucetDirect;
	}

	public void setOnFaucetDirect(Boolean onFaucetDirect) {
		this.onFaucetDirect = onFaucetDirect;
	}

	public Boolean getOnToolsDirect() {
		return onToolsDirect;
	}

	public void setOnToolsDirect(Boolean onToolsDirect) {
		this.onToolsDirect = onToolsDirect;
	}

	public Boolean getOnMoreHome() {
		return onMoreHome;
	}

	public void setOnMoreHome(Boolean onMoreHome) {
		this.onMoreHome = onMoreHome;
	}

	public Boolean getOnLightingDirect() {
		return onLightingDirect;
	}

	public void setOnLightingDirect(Boolean onLightingDirect) {
		this.onLightingDirect = onLightingDirect;
	}

	public Boolean getOnITankless() {
		return onITankless;
	}

	public void setOnITankless(Boolean onITankless) {
		this.onITankless = onITankless;
	}

	public Boolean getOnStockBlowout() {
		return onStockBlowout;
	}

	public void setOnStockBlowout(Boolean onStockBlowout) {
		this.onStockBlowout = onStockBlowout;
	}

	public Boolean getOnVentingDirect() {
		return onVentingDirect;
	}

	public void setOnVentingDirect(Boolean onVentingDirect) {
		this.onVentingDirect = onVentingDirect;
	}

	public Boolean getOnPullsDirect() {
		return onPullsDirect;
	}

	public void setOnPullsDirect(Boolean onPullsDirect) {
		this.onPullsDirect = onPullsDirect;
	}

	public Boolean getOnFaucetDirectCoUk() {
		return onFaucetDirectCoUk;
	}

	public void setOnFaucetDirectCoUk(Boolean onFaucetDirectCoUk) {
		this.onFaucetDirectCoUk = onFaucetDirectCoUk;
	}

	public Boolean getOnHandlesets() {
		return onHandlesets;
	}

	public void setOnHandlesets(Boolean onHandlesets) {
		this.onHandlesets = onHandlesets;
	}

	public Boolean getOnLightingCentral() {
		return onLightingCentral;
	}

	public void setOnLightingCentral(Boolean onLightingCentral) {
		this.onLightingCentral = onLightingCentral;
	}

	public Boolean getOnDrillSpot() {
		return onDrillSpot;
	}

	public void setOnDrillSpot(Boolean onDrillSpot) {
		this.onDrillSpot = onDrillSpot;
	}

	public Boolean getOnFixturesDirect() {
		return onFixturesDirect;
	}

	public void setOnFixturesDirect(Boolean onFixturesDirect) {
		this.onFixturesDirect = onFixturesDirect;
	}

	public Boolean getOnImprovementDirectReMerch() {
		return onImprovementDirectReMerch;
	}

	public void setOnImprovementDirectReMerch(Boolean onImprovementDirectReMerch) {
		this.onImprovementDirectReMerch = onImprovementDirectReMerch;
	}

	public Boolean getOnDoorsDirect() {
		return onDoorsDirect;
	}

	public void setOnDoorsDirect(Boolean onDoorsDirect) {
		this.onDoorsDirect = onDoorsDirect;
	}

	public Boolean getOnVentingPipe() {
		return onVentingPipe;
	}

	public void setOnVentingPipe(Boolean onVentingPipe) {
		this.onVentingPipe = onVentingPipe;
	}

	public Boolean getOnFergusonCounters() {
		return onFergusonCounters;
	}

	public void setOnFergusonCounters(Boolean onFergusonCounters) {
		this.onFergusonCounters = onFergusonCounters;
	}

	public Boolean getOnShopStockBuilding() {
		return onShopStockBuilding;
	}

	public void setOnShopStockBuilding(Boolean onShopStockBuilding) {
		this.onShopStockBuilding = onShopStockBuilding;
	}

	public Boolean getOnBathFans() {
		return onBathFans;
	}

	public void setOnBathFans(Boolean onBathFans) {
		this.onBathFans = onBathFans;
	}

	public Boolean getOnRangeHoodsDirect() {
		return onRangeHoodsDirect;
	}

	public void setOnRangeHoodsDirect(Boolean onRangeHoodsDirect) {
		this.onRangeHoodsDirect = onRangeHoodsDirect;
	}

	public Boolean getOnShowerSystemsDirect() {
		return onShowerSystemsDirect;
	}

	public void setOnShowerSystemsDirect(Boolean onShowerSystemsDirect) {
		this.onShowerSystemsDirect = onShowerSystemsDirect;
	}

	public Boolean getOnJustChandeliers() {
		return onJustChandeliers;
	}

	public void setOnJustChandeliers(Boolean onJustChandeliers) {
		this.onJustChandeliers = onJustChandeliers;
	}

	public Boolean getOnB2bChannel() {
		return onB2bChannel;
	}

	public void setOnB2bChannel(Boolean onB2bChannel) {
		this.onB2bChannel = onB2bChannel;
	}

	public Boolean getOnKnobsets() {
		return onKnobsets;
	}

	public void setOnKnobsets(Boolean onKnobsets) {
		this.onKnobsets = onKnobsets;
	}

	public Boolean getOnImprovementDirect() {
		return onImprovementDirect;
	}

	public void setOnImprovementDirect(Boolean onImprovementDirect) {
		this.onImprovementDirect = onImprovementDirect;
	}

	public Boolean getOnPlumbingDirect() {
		return onPlumbingDirect;
	}

	public void setOnPlumbingDirect(Boolean onPlumbingDirect) {
		this.onPlumbingDirect = onPlumbingDirect;
	}

	public Boolean getOnBuild() {
		return onBuild;
	}

	public void setOnBuild(Boolean onBuild) {
		this.onBuild = onBuild;
	}

	public Boolean getOnFaucet() {
		return onFaucet;
	}

	public void setOnFaucet(Boolean onFaucet) {
		this.onFaucet = onFaucet;
	}

	public Boolean getOnLightingShowplace() {
		return onLightingShowplace;
	}

	public void setOnLightingShowplace(Boolean onLightingShowplace) {
		this.onLightingShowplace = onLightingShowplace;
	}

	public Boolean getOnFloorMall() {
		return onFloorMall;
	}

	public void setOnFloorMall(Boolean onFloorMall) {
		this.onFloorMall = onFloorMall;
	}

	public List<ProductQuestion> getProductQuestions() {
		return productQuestions;
	}

	public void setProductQuestions(List<ProductQuestion> productQuestions) {
		this.productQuestions = productQuestions;
	}

}
